@@ -13,7 +13,7 @@ def write_star(particles, file_path, features=None, overwrite=False):
     df[Relion.COORD_HEADERS] = particles.data[Naaf.COORD_HEADERS]
     rot = Rotation.concatenate(particles.data[Naaf.ROT_HEADER])
     # we use the inverse rotation in naaf
-    df[Relion.EULER_HEADERS[3]] = rot.inv().as_euler(Relion.EULER, degrees=True)
+    df[Relion.EULER_HEADERS] = rot.inv().as_euler(Relion.EULER, degrees=True)
 
     features = particles.data.drop(columns=Relion.ALL_HEADERS, errors='ignore')
     df = pd.concat([df, features], axis=1)
